Author: akhaldi
Date: Sat Nov 12 20:53:49 2016
New Revision: 73215

URL: http://svn.reactos.org/svn/reactos?rev=73215&view=rev
Log:
[BOOT] Spelling fixes by Josh Soref. CORE-12286

Modified:
    trunk/reactos/boot/bootdata/bootcdregtest/testboot.bat.sample
    trunk/reactos/boot/bootdata/hivesys.inf
    trunk/reactos/boot/environ/app/bootmgr/bootmgr.c
    trunk/reactos/boot/environ/include/bcd.h
    trunk/reactos/boot/environ/include/efi/BlockIo.h
    trunk/reactos/boot/environ/include/efi/ProcessorBind.h
    trunk/reactos/boot/environ/include/efi/SimpleTextOut.h
    trunk/reactos/boot/environ/include/efi/UefiSpec.h
    trunk/reactos/boot/environ/include/efi/UgaDraw.h
    trunk/reactos/boot/environ/lib/firmware/efi/firmware.c
    trunk/reactos/boot/environ/lib/io/device.c
    trunk/reactos/boot/environ/lib/io/display/display.c
    trunk/reactos/boot/environ/lib/io/display/efi/gop.c
    trunk/reactos/boot/environ/lib/io/display/efi/textcons.c
    trunk/reactos/boot/environ/lib/io/display/guicons.c
    trunk/reactos/boot/environ/lib/io/etfs.c
    trunk/reactos/boot/environ/lib/io/file.c
    trunk/reactos/boot/environ/lib/misc/bcd.c
    trunk/reactos/boot/environ/lib/misc/image.c
    trunk/reactos/boot/environ/lib/misc/util.c
    trunk/reactos/boot/environ/lib/mm/blkalloc.c
    trunk/reactos/boot/environ/lib/mm/descriptor.c
    trunk/reactos/boot/environ/lib/mm/mm.c
    trunk/reactos/boot/freeldr/bootsect/ext2.S
    trunk/reactos/boot/freeldr/bootsect/ext2.asm
    trunk/reactos/boot/freeldr/fdebug/fdebug.c
    trunk/reactos/boot/freeldr/freeldr/CHANGELOG
    trunk/reactos/boot/freeldr/freeldr/arch/arm/macharm.c
    trunk/reactos/boot/freeldr/freeldr/arch/i386/hardware.c
    trunk/reactos/boot/freeldr/freeldr/arch/i386/i386trap.S
    trunk/reactos/boot/freeldr/freeldr/arch/i386/pcvideo.c
    trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c
    trunk/reactos/boot/freeldr/freeldr/bootmgr.c
    trunk/reactos/boot/freeldr/freeldr/cache/cache.c
    trunk/reactos/boot/freeldr/freeldr/freeldr.c
    trunk/reactos/boot/freeldr/freeldr/include/freeldr.h
    trunk/reactos/boot/freeldr/freeldr/lib/fs/fat.c
    trunk/reactos/boot/freeldr/freeldr/lib/mm/heap.c
    trunk/reactos/boot/freeldr/freeldr/lib/mm/meminit.c
    trunk/reactos/boot/freeldr/freeldr/lib/peloader.c
    trunk/reactos/boot/freeldr/freeldr/ntldr/arch/i386/winldr.c
    trunk/reactos/boot/freeldr/freeldr/ntldr/setupldr.c
    trunk/reactos/boot/freeldr/freeldr/ntldr/winldr.c
    trunk/reactos/boot/freeldr/freeldr/ntldr/wlregistry.c
    trunk/reactos/boot/freeldr/freeldr/options.c
    trunk/reactos/boot/freeldr/freeldr/ui/ui.c
    trunk/reactos/boot/freeldr/tools/rdel.c
    trunk/reactos/boot/freeldr/tools/rrmdir.c

Modified: trunk/reactos/boot/bootdata/bootcdregtest/testboot.bat.sample
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/bootdata/bootcdregtest/testboot.bat.sample?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/bootdata/bootcdregtest/testboot.bat.sample       
[iso-8859-1] (original)
+++ trunk/reactos/boot/bootdata/bootcdregtest/testboot.bat.sample       
[iso-8859-1] Sat Nov 12 20:53:49 2016
@@ -1,6 +1,6 @@
 @echo off
 ECHO 
-ECHO Installing Programms...
+ECHO Installing Programs...
 ECHO
 
 REM ECHO

Modified: trunk/reactos/boot/bootdata/hivesys.inf
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/bootdata/hivesys.inf?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/bootdata/hivesys.inf     [iso-8859-1] (original)
+++ trunk/reactos/boot/bootdata/hivesys.inf     [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -1551,7 +1551,7 @@
 
 ; Workstation service
 
HKLM,"SYSTEM\CurrentControlSet\Services\lanmanworkstation","DisplayName",0x00000000,"Workstation
 service"
-HKLM,"SYSTEM\CurrentControlSet\Services\lanmanworkstation","Description",0x00000000,"Responsible
 for creating and maintaning network connections to servers"
+HKLM,"SYSTEM\CurrentControlSet\Services\lanmanworkstation","Description",0x00000000,"Responsible
 for creating and maintaining network connections to servers"
 
HKLM,"SYSTEM\CurrentControlSet\Services\lanmanworkstation","ErrorControl",0x00010001,0x00000001
 
HKLM,"SYSTEM\CurrentControlSet\Services\lanmanworkstation","Group",0x00000000,"Network
 Provider"
 
HKLM,"SYSTEM\CurrentControlSet\Services\lanmanworkstation","ImagePath",0x00020000,"%SystemRoot%\system32\svchost.exe
 -k netsvcs"

Modified: trunk/reactos/boot/environ/app/bootmgr/bootmgr.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/app/bootmgr/bootmgr.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/app/bootmgr/bootmgr.c    [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/app/bootmgr/bootmgr.c    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -274,7 +274,7 @@
                                   AppPathLength - sizeof(UNICODE_NULL));
                     PathCopy[AppPathLength] = UNICODE_NULL;
 
-                    /* Finally, initialize the outoing string */
+                    /* Finally, initialize the outgoing string */
                     RtlInitUnicodeString(ApplicationDirectoryPath, PathCopy);
                 }
                 else
@@ -1088,7 +1088,7 @@
     VOID
     )
 {
-    /* Check if we're booted by UEFI off the DVD directlry */
+    /* Check if we're booted by UEFI off the DVD directly */
     if ((BlpBootDevice->DeviceType == LocalDevice) &&
         (BlpBootDevice->Local.Type == CdRomDevice) &&
         (BlpApplicationFlags & BL_APPLICATION_FLAG_CONVERTED_FROM_EFI))
@@ -1729,7 +1729,7 @@
             return MenuPolicyLegacy;
         }
 
-        /* Use the correct opetion ID */
+        /* Use the correct option ID */
         OptionId = BcdResumeInteger_BootMenuPolicy;
     }
 
@@ -1783,7 +1783,7 @@
     /* If the legacy menu must be shown, or if we have a boot entry */
     if ((BmGetBootMenuPolicy(BootEntry) != MenuPolicyStandard) || (BootEntry))
     {
-        /* Check if any key has been presseed */
+        /* Check if any key has been pressed */
         BmDisplayGetBootMenuStatus(&MenuStatus);
         if (MenuStatus.AnyKey)
         {
@@ -2383,22 +2383,22 @@
     }
     else if (ReturnArgs.Flags & 4)
     {
-        /* Flag 4 -- unkown */
+        /* Flag 4 -- unknown */
         *LaunchCode = 1;
     }
     else if (ReturnArgs.Flags & 8)
     {
-        /* Flag 5 -- unkown */
+        /* Flag 5 -- unknown */
         *LaunchCode = 5;
     }
     else if (ReturnArgs.Flags & 0x10)
     {
-        /* Flag 6 -- unkown */
+        /* Flag 6 -- unknown */
         *LaunchCode = 6;
     }
     else if (ReturnArgs.Flags & 0x20)
     {
-        /* Flag 7 -- unkown */
+        /* Flag 7 -- unknown */
         *LaunchCode = 7;
     }
     else if (ReturnArgs.Flags & BL_RETURN_ARGUMENTS_NO_PAE_FLAG)
@@ -2558,7 +2558,7 @@
         return Status;
     }
 
-    /* Check if boot was successfull, or  cancelled and we're not doing WinRE 
*/
+    /* Check if boot was successful, or  cancelled and we're not doing WinRE */
     if (((NT_SUCCESS(Status)) || (Status == STATUS_CANCELLED)) && 
!(DoRecovery))
     {
         return Status;
@@ -2898,7 +2898,7 @@
     /* Write out the first XML tag */
     BlXmiWrite(L"<bootmgr/>");
 
-    /* Check for factory resset */
+    /* Check for factory reset */
     BlSecureBootCheckForFactoryReset();
 
     /* Load the revocation list */
@@ -2947,7 +2947,7 @@
                                     &CustomActions);
     if ((NT_SUCCESS(Status)) && (CustomActions))
     {
-        /* We don't suppport this yet */
+        /* We don't support this yet */
         EfiPrintf(L"Not implemented\r\n");
         Status = STATUS_NOT_IMPLEMENTED;
         goto Failure;

Modified: trunk/reactos/boot/environ/include/bcd.h
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/bcd.h?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/include/bcd.h    [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/bcd.h    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -42,7 +42,7 @@
 #define BCD_APPLICATION_TYPE_STARTUPCOM 0x09
 
 #define BCD_OBJECT_TYPE_APPLICATION     0x01
-#define BCD_OBJECT_TYPE_INHEREIT        0x02
+#define BCD_OBJECT_TYPE_INHERIT         0x02
 #define BCD_OBJECT_TYPE_DEVICE          0x03
 
 typedef enum BcdLibraryElementTypes

Modified: trunk/reactos/boot/environ/include/efi/BlockIo.h
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/BlockIo.h?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/include/efi/BlockIo.h    [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/BlockIo.h    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -96,7 +96,7 @@
   @retval EFI_WRITE_PROTECTED   The device can not be written to.
   @retval EFI_DEVICE_ERROR      The device reported an error while performing 
the write.
   @retval EFI_NO_MEDIA          There is no media in the device.
-  @retval EFI_MEDIA_CHNAGED     The MediaId does not matched the current 
device.
+  @retval EFI_MEDIA_CHANGED     The MediaId does not match the current device.
   @retval EFI_BAD_BUFFER_SIZE   The Buffer was not a multiple of the block 
size of the device.
   @retval EFI_INVALID_PARAMETER The write request contains LBAs that are not 
valid, 
                                 or the buffer is not on proper alignment.
@@ -118,7 +118,7 @@
   @param  This              Indicates a pointer to the calling context.
 
   @retval EFI_SUCCESS       All outstanding data was written to the device
-  @retval EFI_DEVICE_ERROR  The device reported an error while writting back 
the data
+  @retval EFI_DEVICE_ERROR  The device reported an error while writing back 
the data
   @retval EFI_NO_MEDIA      There is no media in the device.
 
 **/
@@ -133,7 +133,7 @@
 **/
 typedef struct {
   ///
-  /// The curent media Id. If the media changes, this value is changed.
+  /// The current media Id. If the media changes, this value is changed.
   ///
   UINT32  MediaId;         
    
@@ -144,7 +144,7 @@
   
   ///
   /// TRUE if there is a media currently present in the device;
-  /// othersise, FALSE. THis field shows the media present status
+  /// otherwise, FALSE. THis field shows the media present status
   /// as of the most recent ReadBlocks() or WriteBlocks() call.  
   ///
   BOOLEAN MediaPresent;

Modified: trunk/reactos/boot/environ/include/efi/ProcessorBind.h
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/ProcessorBind.h?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/include/efi/ProcessorBind.h      [iso-8859-1] 
(original)
+++ trunk/reactos/boot/environ/include/efi/ProcessorBind.h      [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -79,7 +79,7 @@
 #pragma warning ( disable : 4057 )
 
 //
-// ASSERT(FALSE) or while (TRUE) are legal constructes so supress this warning
+// ASSERT(FALSE) or while (TRUE) are legal constructs so suppress this warning
 //
 #pragma warning ( disable : 4127 )
 

Modified: trunk/reactos/boot/environ/include/efi/SimpleTextOut.h
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/SimpleTextOut.h?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/include/efi/SimpleTextOut.h      [iso-8859-1] 
(original)
+++ trunk/reactos/boot/environ/include/efi/SimpleTextOut.h      [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -146,10 +146,10 @@
 #define EFI_WIDE_ATTRIBUTE  0x80
 
 /**
-Reset the text output device hardware and optionaly run diagnostics
+Reset the text output device hardware and optionally run diagnostics
 
 @param  This                 The protocol instance pointer.
-@param  ExtendedVerification Driver may perform more exhaustive verfication
+@param  ExtendedVerification Driver may perform more exhaustive verification
 operation of the device during reset.
 
 @retval EFI_SUCCESS          The text output device was reset.
@@ -368,7 +368,7 @@
     ///
     INT32   CursorRow;
     ///
-    /// The cursor is currently visbile or not.
+    /// The cursor is currently visible or not.
     ///
     BOOLEAN CursorVisible;
 } EFI_SIMPLE_TEXT_OUTPUT_MODE;

Modified: trunk/reactos/boot/environ/include/efi/UefiSpec.h
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/UefiSpec.h?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/include/efi/UefiSpec.h   [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/UefiSpec.h   [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -817,7 +817,7 @@
 
 @retval EFI_SUCCESS           Image was loaded into memory correctly.
 @retval EFI_NOT_FOUND         Both SourceBuffer and DevicePath are NULL.
-@retval EFI_INVALID_PARAMETER One or more parametes are invalid.
+@retval EFI_INVALID_PARAMETER One or more parameters are invalid.
 @retval EFI_UNSUPPORTED       The image type is not supported.
 @retval EFI_OUT_OF_RESOURCES  Image was not loaded due to insufficient 
resources.
 @retval EFI_LOAD_ERROR        Image was not loaded because the image format 
was corrupt or not
@@ -969,7 +969,7 @@
     ///
     /// Used to induce a system-wide reset. This sets all circuitry within the 
     /// system to its initial state.  This type of reset is asynchronous to 
system
-    /// operation and operates withgout regard to cycle boundaries.  
EfiColdReset 
+    /// operation and operates without regard to cycle boundaries.  
EfiColdReset 
     /// is tantamount to a system power cycle.
     ///
     EfiResetCold,
@@ -1277,7 +1277,7 @@
 @retval EFI_UNSUPPORTED       Handle does not support Protocol.
 @retval EFI_INVALID_PARAMETER One or more parameters are invalid.
 @retval EFI_ACCESS_DENIED     Required attributes can't be supported in 
current environment.
-@retval EFI_ALREADY_STARTED   Item on the open list already has requierd 
attributes whose agent
+@retval EFI_ALREADY_STARTED   Item on the open list already has required 
attributes whose agent
 handle is the same as AgentHandle.
 
 **/
@@ -1637,13 +1637,13 @@
 @param  CapsuleHeaderArray    Virtual pointer to an array of virtual pointers 
to the capsules
 being passed into update capsule.
 @param  CapsuleCount          Number of pointers to EFI_CAPSULE_HEADER in
-CaspuleHeaderArray.
+CapsuleHeaderArray.
 @param  ScatterGatherList     Physical pointer to a set of
 EFI_CAPSULE_BLOCK_DESCRIPTOR that describes the
 location in physical memory of a set of capsules.
 
 @retval EFI_SUCCESS           Valid capsule was passed. If
-CAPSULE_FLAGS_PERSIT_ACROSS_RESET is not set, the
+CAPSULE_FLAGS_PERSIST_ACROSS_RESET is not set, the
 capsule has been successfully processed by the firmware.
 @retval EFI_INVALID_PARAMETER CapsuleSize is NULL, or an incompatible set of 
flags were
 set in the capsule header.
@@ -1667,8 +1667,8 @@
 @param  CapsuleHeaderArray    Virtual pointer to an array of virtual pointers 
to the capsules
 being passed into update capsule.
 @param  CapsuleCount          Number of pointers to EFI_CAPSULE_HEADER in
-CaspuleHeaderArray.
-@param  MaxiumCapsuleSize     On output the maximum size that UpdateCapsule() 
can
+CapsuleHeaderArray.
+@param  MaximumCapsuleSize     On output the maximum size that UpdateCapsule() 
can
 support as an argument to UpdateCapsule() via
 CapsuleHeaderArray and ScatterGatherList.
 @param  ResetType             Returns the type of reset required for the 
capsule update.

Modified: trunk/reactos/boot/environ/include/efi/UgaDraw.h
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/include/efi/UgaDraw.h?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/io/device.c  [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/io/device.c  [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -600,7 +600,7 @@
     _Out_ PBL_DEVICE_INFORMATION DeviceInformation
     )
 {
-    /* Copy the device speciifc data into the block device information */
+    /* Copy the device specific data into the block device information */
     RtlCopyMemory(&DeviceInformation->BlockDeviceInfo,
                    DeviceEntry->DeviceSpecificData,
                    sizeof(DeviceInformation->BlockDeviceInfo));
@@ -1002,7 +1002,7 @@
         return Status;
     }
 
-    /* Iteratate twice -- once for the top level, once for the bottom */
+    /* Iterate twice -- once for the top level, once for the bottom */
     for (i = 0, Found = FALSE; Found == FALSE && Protocol[i].Handle; i++)
     {
         /* Check what kind of leaf node device this is */
@@ -2237,7 +2237,7 @@
         Status = STATUS_NOT_IMPLEMENTED;
     }
 
-    /* Check if the device was opened successfuly */
+    /* Check if the device was opened successfully */
     if (NT_SUCCESS(Status))
     {
 DeviceOpened:

Modified: trunk/reactos/boot/environ/lib/io/display/display.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/io/display/display.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/io/display/display.c [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/io/display/display.c [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -600,7 +600,7 @@
         Status = DsppInitialize(Flags);
     }
 
-    /* Return display initailziation state */
+    /* Return display initialization state */
     return Status;
 }
 

Modified: trunk/reactos/boot/environ/lib/io/display/efi/gop.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/io/display/efi/gop.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/io/display/efi/gop.c [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/io/display/efi/gop.c [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -164,7 +164,7 @@
     }
     else if (CurrentMode != GraphicsConsole->Mode)
     {
-        /* We failed seomewhere, reset the mode and the OEM bitmap back */
+        /* We failed somewhere, reset the mode and the OEM bitmap back */
         EfiGopSetMode(Protocol, CurrentMode);
         BlDisplayInvalidateOemBitmap();
     }

Modified: trunk/reactos/boot/environ/lib/io/display/efi/textcons.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/io/display/efi/textcons.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/io/display/efi/textcons.c    [iso-8859-1] 
(original)
+++ trunk/reactos/boot/environ/lib/io/display/efi/textcons.c    [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -358,7 +358,7 @@
                                           &HRes,
                                           &VRes)))
         {
-            /* This mode was succesfully queried. Save the data */
+            /* This mode was successfully queried. Save the data */
             EfiPrintf(L"EFI Firmware Supported Mode %d is H: %d V: %d\r\n", 
Mode, HRes, VRes);
             ModeEntry->HRes = HRes;
             ModeEntry->VRes = VRes;
@@ -600,7 +600,7 @@
             return STATUS_NOT_IMPLEMENTED;
         }
 
-        /* Clear the scren */
+        /* Clear the screen */
         EfiStatus = Console->Protocol->ClearScreen(Console->Protocol);
 
         /* Switch back to protected mode if we came from there */

Modified: trunk/reactos/boot/environ/lib/io/display/guicons.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/io/display/guicons.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/io/display/guicons.c [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/io/display/guicons.c [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -127,7 +127,7 @@
     /* And the size of line we'll have to clear */
     WidthBytes = Width * BytesPerPixel;
 
-    /* Allocat a scanline */
+    /* Allocate a scanline */
     Scanline = BlMmAllocateHeap(WidthBytes);
     if (Scanline)
     {

Modified: trunk/reactos/boot/environ/lib/io/etfs.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/io/etfs.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/io/etfs.c    [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/io/etfs.c    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -635,7 +635,7 @@
         NewFile->Flags |= BL_FILE_ENTRY_DIRECTORY;
     }
 
-    /* Write down the name of the filesytem */
+    /* Write down the name of the filesystem */
     EtfsFile->FsName = L"cdfs";
 
     /* All done, return the file entry, and save the ETFS side */

Modified: trunk/reactos/boot/environ/lib/io/file.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/io/file.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/io/file.c    [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/io/file.c    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -212,7 +212,7 @@
         return STATUS_UNSUCCESSFUL;
     }
 
-    /* Purge the entry othwrwise */
+    /* Purge the entry otherwise */
     return FileTableDestroyEntry(FileEntry, FileEntry->FileId);
 }
 

Modified: trunk/reactos/boot/environ/lib/misc/bcd.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/misc/bcd.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/misc/bcd.c   [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/misc/bcd.c   [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -1028,7 +1028,7 @@
         else if ((Flags & BCD_ENUMERATE_FLAG_DEEP) &&
                  (ElementType.PackedValue == 
BcdLibraryObjectList_InheritedObjects))
         {
-            /* Inherited objects are requsted, so allocate a buffer for them */
+            /* Inherited objects are requested, so allocate a buffer for them 
*/
             SubObjectList = BlMmAllocateHeap(ElementDataLength);
             if (!SubObjectList)
             {

Modified: trunk/reactos/boot/environ/lib/misc/image.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/misc/image.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/misc/image.c [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/misc/image.c [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -1186,7 +1186,7 @@
         //MmPapFreePages(HashBuffer, TRUE);
     }
 
-    /* Check if we have a certificate diretory */
+    /* Check if we have a certificate directory */
     if ((CertBuffer) && (CertDirectory))
     {
         /* Free it */

Modified: trunk/reactos/boot/environ/lib/misc/util.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/misc/util.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/misc/util.c  [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/misc/util.c  [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -221,7 +221,7 @@
 
 VOID
 BmUpdateProgressInfo (
-    _In_ PVOID Uknown,
+    _In_ PVOID Unknown,
     _In_ PWCHAR ProgressInfo
     )
 {
@@ -307,7 +307,7 @@
                               Argument4);
             if (Result)
             {
-                /* Entry fouund return it */
+                /* Entry found return it */
                 *EntryIndex = Index;
                 Entry = Table[Index];
                 break;
@@ -679,7 +679,7 @@
     PLIST_ENTRY HashLinkHead;
     PBL_HASH_TABLE HashTable;
 
-    /* Check for invalid tablle ID, missing arguments, or malformed entry */
+    /* Check for invalid table ID, missing arguments, or malformed entry */
     if ((HtTableSize <= TableId) ||
         !(Entry) ||
         !(Data) ||

Modified: trunk/reactos/boot/environ/lib/mm/blkalloc.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/mm/blkalloc.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/mm/blkalloc.c        [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/mm/blkalloc.c        [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -185,7 +185,7 @@
 }
 
 NTSTATUS
-MmBapPurgeBlockAlloctorTableEntry (
+MmBapPurgeBlockAllocatorTableEntry (
     _In_ PVOID Entry
     )
 {
@@ -248,7 +248,7 @@
                            &MmBlockAllocatorTableEntries,
                            BlockInfo,
                            &BlockId,
-                           MmBapPurgeBlockAlloctorTableEntry);
+                           MmBapPurgeBlockAllocatorTableEntry);
     if (NT_SUCCESS(Status))
     {
         /* Add the initial reference and store the block ID */

Modified: trunk/reactos/boot/environ/lib/mm/descriptor.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/mm/descriptor.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/mm/descriptor.c      [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/mm/descriptor.c      [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -44,19 +44,19 @@
     BL_MEMORY_CLASS Class1, Class2;
     ULONG i, j;
 
-    /* Descriptor is free RAM -- it preceeds */
+    /* Descriptor is free RAM -- it precedes */
     if (Type1 == BlConventionalMemory)
     {
         return TRUE;
     }
 
-    /* It isn't free RAM, but the comparator is -- it suceeds it */
+    /* It isn't free RAM, but the comparator is -- it succeeds it */
     if (Type2 == BlConventionalMemory)
     {
         return FALSE;
     }
 
-    /* Descriptor is not system, application, or loader class -- it preceeds */
+    /* Descriptor is not system, application, or loader class -- it precedes */
     Class1 = Type1 >> BL_MEMORY_CLASS_SHIFT;
     if ((Class1 != BlSystemClass) &&
         (Class1 != BlApplicationClass) &&
@@ -65,7 +65,7 @@
         return TRUE;
     }
 
-    /* It isn't one of those classes, but the comparator it -- it suceeds it */
+    /* It isn't one of those classes, but the comparator it -- it succeeds it 
*/
     Class2 = Type2 >> BL_MEMORY_CLASS_SHIFT;
     if ((Class2 != BlSystemClass) &&
         (Class2 != BlApplicationClass) &&
@@ -124,23 +124,23 @@
             }
         }
 
-        /* The comparator isn't system, so it preceeds it */
+        /* The comparator isn't system, so it precedes it */
         return TRUE;
     }
 
-    /* Descriptor is not system class, but comparator is -- it suceeds it */
+    /* Descriptor is not system class, but comparator is -- it succeeds it */
     if (Class2 == BlSystemClass)
     {
         return FALSE;
     }
 
-    /* Descriptor is loader class -- it preceeds */
+    /* Descriptor is loader class -- it precedes */
     if (Class1 == BlLoaderClass)
     {
         return TRUE;
     }
 
-    /* It isn't loader class  -- if the other guy is, suceed it */
+    /* It isn't loader class  -- if the other guy is, succeed it */
     return Class2 != BlLoaderClass;
 }
 
@@ -343,7 +343,7 @@
           ((MemoryDescriptor->VirtualPage) && 
(PreviousDescriptor->VirtualPage) &&
            (PreviousMappedEndPage == MemoryDescriptor->VirtualPage))))
     {
-        EfiPrintf(L"Previous descriptor coalescible!\r\n");
+        EfiPrintf(L"Previous descriptor coalescable!\r\n");
     }
 
     /* CHeck if the current entry touches the next entry, and is compatible */
@@ -355,7 +355,7 @@
             ((MemoryDescriptor->VirtualPage) && 
(PreviousDescriptor->VirtualPage) &&
                 (MappedEndPage == NextDescriptor->VirtualPage))))
     {
-        EfiPrintf(L"Next descriptor coalescible!\r\n");
+        EfiPrintf(L"Next descriptor coalescable!\r\n");
     }
 
     /* Nothing to do */

Modified: trunk/reactos/boot/environ/lib/mm/mm.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/mm/mm.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/mm/mm.c      [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/lib/mm/mm.c      [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -208,7 +208,7 @@
         goto Quickie;
     }
 
-    /* Compute the final adress where the mapping was made */
+    /* Compute the final address where the mapping was made */
     MappedBase = (PVOID)((ULONG_PTR)MappingAddress +
                          PhysicalAddress.LowPart -
                          MappedAddress.LowPart);
@@ -274,7 +274,7 @@
     /* Increment call depth */
     ++MmDescriptorCallTreeCount;
 
-    /* Make sure all parameters are tehre */
+    /* Make sure all parameters are there */
     if ((VirtualAddress) && (Size))
     {
         /* Unmap the virtual address */

Modified: trunk/reactos/boot/freeldr/bootsect/ext2.S
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/bootsect/ext2.S?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/bootsect/ext2.S  [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/bootsect/ext2.S  [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -597,7 +597,7 @@
 // ECX contains the max number of blocks to read
 // EAX contains the number of blocks left to read
 // On return:
-//  EAX contians the new number of blocks left to read
+//  EAX contains the new number of blocks left to read
 Ext2ReadDirectBlockList:
                cmp  eax,ecx                                                    
                        // Compare it to the maximum number of blocks to read
                ja   CallExt2ReadDirectBlocks                                   
        // If it will take more blocks then just read all of the blocks

Modified: trunk/reactos/boot/freeldr/bootsect/ext2.asm
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/bootsect/ext2.asm?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/bootsect/ext2.asm        [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/bootsect/ext2.asm        [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -584,7 +584,7 @@
 ; ECX contains the max number of blocks to read
 ; EAX contains the number of blocks left to read
 ; On return:
-;  EAX contians the new number of blocks left to read
+;  EAX contains the new number of blocks left to read
 Ext2ReadDirectBlockList:
                cmp  eax,ecx                                                    
                        ; Compare it to the maximum number of blocks to read
                ja   CallExt2ReadDirectBlocks                                   
        ; If it will take more blocks then just read all of the blocks

Modified: trunk/reactos/boot/freeldr/fdebug/fdebug.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/fdebug/fdebug.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/fdebug/fdebug.c  [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/fdebug/fdebug.c  [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -30,7 +30,7 @@
 HANDLE        hCaptureFile;                                // Handle to the 
capture file
 DWORD        dwThreadId = 0;                                // Thread id of 
RS232 communication thread
 
-// Foward declarations of functions included in this code module:
+// Forward declarations of functions included in this code module:
 ATOM                MyRegisterClass(HINSTANCE hInstance);
 BOOL                InitInstance(HINSTANCE, int);
 LRESULT CALLBACK    WndProc(HWND, UINT, WPARAM, LPARAM);

Modified: trunk/reactos/boot/freeldr/freeldr/CHANGELOG
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/CHANGELOG?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/CHANGELOG        [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/CHANGELOG        [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -223,7 +223,7 @@
 Changes in v1.7.6 (8/31/2002) (ekohl)
 
 - bootsect/isoboot.asm: Reduced read transfer size to ensure that
-  the read buffer for an int13/ah=42h (exended read) does not
+  the read buffer for an int13/ah=42h (extended read) does not
   cross a segment boundary.
 - freeldr.c, bootmgr.c, setupldr.c, makefile: Renamed
   LoadBootManager() and ReactOSRunSetupLoader() to RunLoader().

Modified: trunk/reactos/boot/freeldr/freeldr/arch/arm/macharm.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/arm/macharm.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/arm/macharm.c       [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/arm/macharm.c       [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -66,7 +66,7 @@
 }
 
 VOID
-FrLdrCheckCpuCompatiblity(VOID)
+FrLdrCheckCpuCompatibility(VOID)
 {
     /* Nothing for now */
 }

Modified: trunk/reactos/boot/freeldr/freeldr/arch/i386/hardware.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/i386/hardware.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/i386/hardware.c     [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/i386/hardware.c     [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -296,7 +296,7 @@
     /* The buffer starts after PartialResourceList->PartialDescriptors[0] */
     Ptr = (char *)(PartialResourceList + 1);
 
-    /* Set instalation check data */
+    /* Set installation check data */
     memcpy (Ptr, InstData, sizeof(CM_PNP_BIOS_INSTALLATION_CHECK));
     Ptr += sizeof(CM_PNP_BIOS_INSTALLATION_CHECK);
 
@@ -1792,7 +1792,7 @@
 }
 
 VOID
-FrLdrCheckCpuCompatiblity(VOID)
+FrLdrCheckCpuCompatibility(VOID)
 {
     INT CpuInformation[4] = {-1};
     ULONG NumberOfIds;

Modified: trunk/reactos/boot/freeldr/freeldr/arch/i386/i386trap.S
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/i386/i386trap.S?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/i386/i386trap.S     [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/i386/i386trap.S     [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -146,7 +146,7 @@
  * DEBUGGING SUPPORT FUNCTIONS
  ************************************************************************/
 
-MACRO(BREAKPOINT_TEPLATE, functionname, mask1, mask2)
+MACRO(BREAKPOINT_TEMPLATE, functionname, mask1, mask2)
     PUBLIC VAL(functionname)
 #ifdef _USE_ML
     functionname:
@@ -164,17 +164,17 @@
     ret
 ENDM
 
-BREAKPOINT_TEPLATE _INSTRUCTION_BREAKPOINT1, HEX(0fff0ffff), HEX(000000303)
-BREAKPOINT_TEPLATE _MEMORY_READWRITE_BREAKPOINT1, HEX(0fff0ffff), 
HEX(000030303)
-BREAKPOINT_TEPLATE _MEMORY_WRITE_BREAKPOINT1, HEX(0fff0ffff), HEX(000010303)
-BREAKPOINT_TEPLATE _INSTRUCTION_BREAKPOINT2, HEX(0ff0fffff), HEX(00000030c)
-BREAKPOINT_TEPLATE _MEMORY_READWRITE_BREAKPOINT2, HEX(0ff0fffff), 
HEX(00030030c)
-BREAKPOINT_TEPLATE _MEMORY_WRITE_BREAKPOINT2, HEX(0ff0fffff), HEX(00010030c)
-BREAKPOINT_TEPLATE _INSTRUCTION_BREAKPOINT3, HEX(0f0ffffff), HEX(000000330)
-BREAKPOINT_TEPLATE _MEMORY_READWRITE_BREAKPOINT3, HEX(0f0ffffff), 
HEX(003000330)
-BREAKPOINT_TEPLATE _MEMORY_WRITE_BREAKPOINT3, HEX(0f0ffffff), HEX(001000330)
-BREAKPOINT_TEPLATE _INSTRUCTION_BREAKPOINT4, HEX(00fffffff), HEX(0000003c0)
-BREAKPOINT_TEPLATE _MEMORY_READWRITE_BREAKPOINT4, HEX(00fffffff), 
HEX(0300003c0)
-BREAKPOINT_TEPLATE _MEMORY_WRITE_BREAKPOINT4, HEX(00fffffff), HEX(0100003c0)
+BREAKPOINT_TEMPLATE _INSTRUCTION_BREAKPOINT1, HEX(0fff0ffff), HEX(000000303)
+BREAKPOINT_TEMPLATE _MEMORY_READWRITE_BREAKPOINT1, HEX(0fff0ffff), 
HEX(000030303)
+BREAKPOINT_TEMPLATE _MEMORY_WRITE_BREAKPOINT1, HEX(0fff0ffff), HEX(000010303)
+BREAKPOINT_TEMPLATE _INSTRUCTION_BREAKPOINT2, HEX(0ff0fffff), HEX(00000030c)
+BREAKPOINT_TEMPLATE _MEMORY_READWRITE_BREAKPOINT2, HEX(0ff0fffff), 
HEX(00030030c)
+BREAKPOINT_TEMPLATE _MEMORY_WRITE_BREAKPOINT2, HEX(0ff0fffff), HEX(00010030c)
+BREAKPOINT_TEMPLATE _INSTRUCTION_BREAKPOINT3, HEX(0f0ffffff), HEX(000000330)
+BREAKPOINT_TEMPLATE _MEMORY_READWRITE_BREAKPOINT3, HEX(0f0ffffff), 
HEX(003000330)
+BREAKPOINT_TEMPLATE _MEMORY_WRITE_BREAKPOINT3, HEX(0f0ffffff), HEX(001000330)
+BREAKPOINT_TEMPLATE _INSTRUCTION_BREAKPOINT4, HEX(00fffffff), HEX(0000003c0)
+BREAKPOINT_TEMPLATE _MEMORY_READWRITE_BREAKPOINT4, HEX(00fffffff), 
HEX(0300003c0)
+BREAKPOINT_TEMPLATE _MEMORY_WRITE_BREAKPOINT4, HEX(00fffffff), HEX(0100003c0)
 
 END

Modified: trunk/reactos/boot/freeldr/freeldr/arch/i386/pcvideo.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/i386/pcvideo.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/i386/pcvideo.c      [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/i386/pcvideo.c      [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -352,7 +352,7 @@
    * Return:
    * AL = 12h if function supported
    *
-   * Specifiy the number of scan lines used to display text modes.
+   * Specify the number of scan lines used to display text modes.
    *
    * The specified resolution will take effect on the next mode set.
    */

Modified: trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c     [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/arch/powerpc/mboot.c     [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -359,7 +359,7 @@
  * FrLdrGetPaeMode
  * INTERNAL
  *
- *     Determines whether PAE mode shoudl be enabled or not.
+ *     Determines whether PAE mode should be enabled or not.
  *
  * Params:
  *     None.
@@ -390,7 +390,7 @@
  *     None.
  *
  * Remarks:
- *     We are setting PDEs, but using the equvivalent (for our purpose) PTE 
structure.
+ *     We are setting PDEs, but using the equivalent (for our purpose) PTE 
structure.
  *     As such, please note that PageFrameNumber == PageEntryNumber.
  *
  *--*/

Modified: trunk/reactos/boot/freeldr/freeldr/bootmgr.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/bootmgr.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/bootmgr.c        [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/bootmgr.c        [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -73,7 +73,7 @@
 
     if (BootType[0] == ANSI_NULL && SectionName[0] != ANSI_NULL)
     {
-        /* Try to infere the boot type value */
+        /* Try to infer the boot type value */
 #ifdef _M_IX86
         ULONG FileId;
         if (ArcOpen((PSTR)SectionName, OpenReadOnly, &FileId) == ESUCCESS)

Modified: trunk/reactos/boot/freeldr/freeldr/cache/cache.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/cache/cache.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/cache/cache.c    [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/cache/cache.c    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -133,7 +133,7 @@
     }
 
     //
-    // Caculate which blocks we must cache
+    // Calculate which blocks we must cache
     //
     StartBlock = (ULONG)(StartSector / CacheManagerDrive.BlockSize);
     SectorOffsetInStartBlock = (ULONG)(StartSector % 
CacheManagerDrive.BlockSize);
@@ -263,7 +263,7 @@
     }
 
     //
-    // Caculate which blocks we must cache
+    // Calculate which blocks we must cache
     //
     StartBlock = StartSector / CacheManagerDrive.BlockSize;
     EndBlock = (StartSector + SectorCount) / CacheManagerDrive.BlockSize;

Modified: trunk/reactos/boot/freeldr/freeldr/freeldr.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/freeldr.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/freeldr.c        [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/freeldr.c        [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -38,7 +38,7 @@
     MachInit(CmdLine);
 
     /* Check if the CPU is new enough */
-    FrLdrCheckCpuCompatiblity(); // FIXME: Should be done inside MachInit!
+    FrLdrCheckCpuCompatibility(); // FIXME: Should be done inside MachInit!
 
     /* UI pre-initialization */
     if (!UiInitialize(FALSE))

Modified: trunk/reactos/boot/freeldr/freeldr/include/freeldr.h
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/include/freeldr.h?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/include/freeldr.h        [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/include/freeldr.h        [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -124,6 +124,6 @@
 VOID __cdecl BootMain(IN PCCH CmdLine);
 VOID LoadOperatingSystem(IN OperatingSystemItem* OperatingSystem);
 VOID RunLoader(VOID);
-VOID FrLdrCheckCpuCompatiblity(VOID);
+VOID FrLdrCheckCpuCompatibility(VOID);
 
 #endif  /* __FREELDR_H */

Modified: trunk/reactos/boot/freeldr/freeldr/lib/fs/fat.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/lib/fs/fat.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/lib/fs/fat.c     [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/lib/fs/fat.c     [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -916,7 +916,7 @@
 
     //TRACE("FatGetFatEntry() Retrieving FAT entry for cluster %d.\n", 
Cluster);
 
-    // We need a buffer for 2 secors
+    // We need a buffer for 2 sectors
     ReadBuffer = FrLdrTempAlloc(2 * Volume->BytesPerSector, TAG_FAT_BUFFER);
     if (!ReadBuffer)
     {

Modified: trunk/reactos/boot/freeldr/freeldr/lib/mm/heap.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/lib/mm/heap.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/lib/mm/heap.c    [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/lib/mm/heap.c    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -370,7 +370,7 @@
         /* Check if the remaining space is large enough for a new block */
         if (Remaining > 1)
         {
-            /* Make the allocated block as large as neccessary */
+            /* Make the allocated block as large as necessary */
             Block->Size = BlockSize;
 
             /* Get pointer to the new block */
@@ -419,7 +419,7 @@
         *REDZONE_LOW(Block) = REDZONE_MARK;
         *REDZONE_HI(Block) = REDZONE_MARK;
 
-        /* Allcoation starts after size field and redzone */
+        /* Allocation starts after size field and redzone */
         return (PUCHAR)Block->Data + REDZONE_LOW_OFFSET;
 #endif
         /* Return pointer to the data */

Modified: trunk/reactos/boot/freeldr/freeldr/lib/mm/meminit.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/lib/mm/meminit.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/lib/mm/meminit.c [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/lib/mm/meminit.c [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -674,7 +674,7 @@
     StartPage -= MmLowestPhysicalPage;
 
     // Make sure they aren't trying to go past the
-    // end of availabe memory
+    // end of available memory
     if ((StartPage + PageCount) > TotalPageCount)
     {
         return FALSE;
@@ -683,7 +683,7 @@
     for (Index = StartPage; Index < (StartPage + PageCount); Index++)
     {
         // If this page is allocated then there obviously isn't
-        // memory availabe so return FALSE
+        // memory available so return FALSE
         if (RealPageLookupTable[Index].PageAllocated != LoaderFree)
         {
             return FALSE;

Modified: trunk/reactos/boot/freeldr/freeldr/lib/peloader.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/lib/peloader.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/lib/peloader.c   [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/lib/peloader.c   [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -631,7 +631,7 @@
                 return FALSE;
             }
 
-            /* Everything allright, get the ordinal */
+            /* Everything alright, get the ordinal */
             Ordinal = OrdinalTable[Middle];
 
             //TRACE("WinLdrpBindImportName() found Ordinal %d\n", Ordinal);

Modified: trunk/reactos/boot/freeldr/freeldr/ntldr/arch/i386/winldr.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/ntldr/arch/i386/winldr.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/ntldr/arch/i386/winldr.c [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/ntldr/arch/i386/winldr.c [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -52,7 +52,7 @@
 {
     ULONG NumPageTables, TotalSize;
     PUCHAR Buffer;
-    // It's better to allocate PDE + PTEs contigiuos
+    // It's better to allocate PDE + PTEs contiguous
 
     // Max number of entries = MaxPageNum >> 10
     // FIXME: This is a number to describe ALL physical memory

Modified: trunk/reactos/boot/freeldr/freeldr/ntldr/setupldr.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/ntldr/setupldr.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/ntldr/setupldr.c [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/ntldr/setupldr.c [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -310,7 +310,7 @@
 
     UiDrawStatusText("Setup is loading...");
 
-    /* Allocate and minimalistic-initialize LPB */
+    /* Allocate and minimalist-initialize LPB */
     AllocateAndInitLPB(&LoaderBlock);
 
     /* Allocate and initialize setup loader block */

Modified: trunk/reactos/boot/freeldr/freeldr/ntldr/winldr.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/ntldr/winldr.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/ntldr/winldr.c   [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/ntldr/winldr.c   [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -441,7 +441,7 @@
     BOOLEAN Success;
     CHAR FullFileName[MAX_PATH];
     CHAR ProgressString[256];
-    PVOID BaseAdress = NULL;
+    PVOID BaseAddress = NULL;
 
     UiDrawBackdrop();
     sprintf(ProgressString, "Loading %s...", File);
@@ -451,13 +451,13 @@
     strcat(FullFileName, "SYSTEM32\\");
     strcat(FullFileName, File);
 
-    Success = WinLdrLoadImage(FullFileName, MemoryType, &BaseAdress);
+    Success = WinLdrLoadImage(FullFileName, MemoryType, &BaseAddress);
     if (!Success)
     {
         TRACE("Loading %s failed\n", File);
         return FALSE;
     }
-    TRACE("%s loaded successfully at %p\n", File, BaseAdress);
+    TRACE("%s loaded successfully at %p\n", File, BaseAddress);
 
     strcpy(FullFileName, "WINDOWS\\SYSTEM32\\");
     strcat(FullFileName, File);
@@ -469,7 +469,7 @@
     Success = WinLdrAllocateDataTableEntry(&LoaderBlock->LoadOrderListHead,
                                            (IsKdTransportDll ? "KDCOM.DLL" : 
File),
                                            FullFileName,
-                                           BaseAdress,
+                                           BaseAddress,
                                            Dte);
 
     return Success;
@@ -692,7 +692,7 @@
 
     TRACE("BootPath: '%s'\n", BootPath);
 
-    /* Allocate and minimalistic-initialize LPB */
+    /* Allocate and minimalist-initialize LPB */
     AllocateAndInitLPB(&LoaderBlock);
 
     /* Load Hive */

Modified: trunk/reactos/boot/freeldr/freeldr/ntldr/wlregistry.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/ntldr/wlregistry.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/ntldr/wlregistry.c       [iso-8859-1] 
(original)
+++ trunk/reactos/boot/freeldr/freeldr/ntldr/wlregistry.c       [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -563,7 +563,7 @@
                     ValueSize = sizeof(TempImagePath);
                     rc = RegQueryValue(hDriverKey, L"ImagePath", NULL, 
(PUCHAR)TempImagePath, &ValueSize);
 
-                    /* Write the whole path if it suceeded, else prepare to 
fail */
+                    /* Write the whole path if it succeeded, else prepare to 
fail */
                     if (rc != ERROR_SUCCESS)
                     {
                         TRACE_CH(REACTOS, "ImagePath: not found\n");

Modified: trunk/reactos/boot/freeldr/freeldr/options.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/options.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/options.c        [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/options.c        [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -53,7 +53,7 @@
 PCSTR FrldrDbgMsg = "Enable FreeLdr debug channels\n"
                     "Acceptable syntax: 
[level1]#channel1[,[level2]#channel2]\n"
                     "level can be one of: trace,warn,fixme,err\n"
-                    "  if the level is ommited all levels\n"
+                    "  if the level is omitted all levels\n"
                     "  are enabled for the specified channel\n"
                     "# can be either + or -\n"
                     "channel can be one of the following:\n"

Modified: trunk/reactos/boot/freeldr/freeldr/ui/ui.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/freeldr/ui/ui.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/freeldr/ui/ui.c  [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/freeldr/ui/ui.c  [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -50,7 +50,7 @@
 BOOLEAN    UiUseSpecialEffects            = FALSE;                // Tells us 
if we should use fade effects
 BOOLEAN    UiDrawTime                    = TRUE;                    // Tells 
us if we should draw the time
 BOOLEAN    UiCenterMenu                = TRUE;                    // Tells us 
if we should use a centered or left-aligned menu
-BOOLEAN    UiMenuBox                    = TRUE;                    // Tells us 
if we shuld draw a box around the menu
+BOOLEAN    UiMenuBox                    = TRUE;                    // Tells us 
if we should draw a box around the menu
 CHAR    UiTimeText[260] = "[Time Remaining: ] ";
 
 const CHAR    UiMonthNames[12][15] = { "January ", "February ", "March ", 
"April ", "May ", "June ", "July ", "August ", "September ", "October ", 
"November ", "December " };

Modified: trunk/reactos/boot/freeldr/tools/rdel.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/tools/rdel.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/tools/rdel.c     [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/tools/rdel.c     [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -1,7 +1,7 @@
 /*
  * COPYRIGHT:             See COPYING in the top level directory
  * PROGRAMMER:            Rex Jolliff ([email protected])
- * PURPOSE:               Platform independant delete command
+ * PURPOSE:               Platform independent delete command
  */
 
 #include <dirent.h>

Modified: trunk/reactos/boot/freeldr/tools/rrmdir.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/freeldr/tools/rrmdir.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/freeldr/tools/rrmdir.c   [iso-8859-1] (original)
+++ trunk/reactos/boot/freeldr/tools/rrmdir.c   [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -2,7 +2,7 @@
  * COPYRIGHT:             See COPYING in the top level directory
  * PROGRAMMER:            Rex Jolliff ([email protected])
  *                        Casper S. Hornstrup ([email protected])
- * PURPOSE:               Platform independant remove directory command
+ * PURPOSE:               Platform independent remove directory command
  */
 
 #include <dirent.h>


Reply via email to
--- trunk/reactos/boot/environ/include/efi/UgaDraw.h    [iso-8859-1] (original)
+++ trunk/reactos/boot/environ/include/efi/UgaDraw.h    [iso-8859-1] Sat Nov 12 
20:53:49 2016
@@ -85,7 +85,7 @@
 } EFI_UGA_PIXEL_UNION;
 
 ///
 /// Enumration value for actions of Blt operations.
 ///
 typedef enum {
   EfiUgaVideoFill,          ///< Write data from the  BltBuffer pixel 
(SourceX, SourceY)
@@ -112,8 +112,8 @@
                             ///< (DestinationX, DestinationY) (DestinationX + 
Width, DestinationY + Height).
                             ///< The BltBuffer and Delta  are not used in this 
mode.
                             
-  EfiUgaBltMax              ///< Maxmimum value for enumration value of Blt 
operation. If a Blt operation
-                            ///< larger or equal to this enumration value, it 
is invalid.
+  EfiUgaBltMax              ///< Maximum value for enumeration value of Blt 
operation. If a Blt operation
+                            ///< larger or equal to this enumeration value, it 
is invalid.
 } EFI_UGA_BLT_OPERATION;
 
 /**
@@ -133,7 +133,7 @@
 
     @retval EFI_SUCCESS           - The Blt operation completed.
     @retval EFI_INVALID_PARAMETER - BltOperation is not valid.
-    @retval EFI_DEVICE_ERROR      - A hardware error occured writting to the 
video buffer.
+    @retval EFI_DEVICE_ERROR      - A hardware error occured writing to the 
video buffer.
 
 **/
 typedef

Modified: trunk/reactos/boot/environ/lib/firmware/efi/firmware.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/firmware/efi/firmware.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================
--- trunk/reactos/boot/environ/lib/firmware/efi/firmware.c      [iso-8859-1] 
(original)
+++ trunk/reactos/boot/environ/lib/firmware/efi/firmware.c      [iso-8859-1] 
Sat Nov 12 20:53:49 2016
@@ -118,7 +118,7 @@
         }
     }
 
-    /* This now contains the deepeest (leaf) node */
+    /* This now contains the deepest (leaf) node */
     return DevicePath;
 }
 
@@ -314,7 +314,7 @@
         *Attributes = LocalAttributes;
     }
 
-    /* Convert the errot to an NTSTATUS and return it */
+    /* Convert the error to an NTSTATUS and return it */
     Status = EfiGetNtStatusCode(EfiStatus);
     return Status;
 }
@@ -1724,7 +1724,7 @@
     NTSTATUS Status = STATUS_SUCCESS;
     EFI_KEY_TOGGLE_STATE KeyToggleState;
 
-    /* Check if we have vaild firmware data */
+    /* Check if we have valid firmware data */
     if (!(FirmwareData) || !(FirmwareData->Version))
     {
         return STATUS_INVALID_PARAMETER;
@@ -85,7 +85,7 @@
 
 ///
-/// Enumration value for actions of Blt operations.
+/// Enumeration value for actions of Blt operations.
 ///
 typedef enum {

Modified: trunk/reactos/boot/environ/lib/io/device.c
URL: 
http://svn.reactos.org/svn/reactos/trunk/reactos/boot/environ/lib/io/device.c?rev=73215&r1=73214&r2=73215&view=diff
==============================================================================